@@ -24,14 +24,7 @@ public:
         ArgumentValue arg("nn", ArgumentType::ARG_NUMERIC);
 
         for (int i : task.getFocusIterator().getSoFar()) {
-            DualChainType chain = task.getNnFocusChain(i);
-            if (chain.empty()) {
-                // special case: empty chain occurs on empty condition and indicates contradiction
-                // (see Task::computeNnFocusChain)
-                arg.push_back(0.0, fociNames[i]);
-            } else {
-                arg.push_back(chain.getSupport(), fociNames[i]);
-            }
+            arg.push_back(task.getNnFocusChain(i).getSum(), fociNames[i]);
         }
 
         arguments.push_back(arg);
