@@ -1,14 +1,16 @@
 #include <testthat.h>
 #include "common.h"
 #include "dig/TaskQueue.h"
+#include "dig/BitChain.h"
+#include "dig/VectorNumChain.h"
 
-using DataType = Data<BitsetBitChain, VectorNumChain<GOGUEN>>;
+using DataType = Data<BitChain, VectorNumChain<GOGUEN>>;
 using TaskType = Task<DataType>;
 
 context("dig/TaskQueue.h") {
     test_that("shorter has priority over longer") {
-        TaskType t0({}, {10, 11, 12});
-        TaskType t1({2, 3}, {10, 11, 12});
+        TaskType t0(Iterator({}, {10, 11, 12}), Iterator());
+        TaskType t1(Iterator({2, 3}, {10, 11, 12}), Iterator());
 
         expect_true(TaskQueue<TaskType>::hasPriority(t0, t1));
         expect_false(TaskQueue<TaskType>::hasPriority(t1, t0));
@@ -16,9 +18,9 @@ context("dig/TaskQueue.h") {
 
     test_that("push & pop") {
         TaskQueue<TaskType> queue;
-        TaskType t0({}, {1, 2, 3});
-        TaskType t1({5}, {1, 2, 3});
-        TaskType t2({5, 6}, {1, 2, 3});
+        TaskType t0(Iterator({}, {1, 2, 3}), Iterator());
+        TaskType t1(Iterator({5}, {1, 2, 3}), Iterator());
+        TaskType t2(Iterator({5, 6}, {1, 2, 3}), Iterator());
 
         expect_true(queue.empty());
 
